@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# $Id: owfs.py 1159 2014-12-04 04:40:32Z mwall $
+# $Id: owfs.py 1318 2015-05-06 10:42:03Z mwall $
 #
 # Copyright 2013 Matthew Wall
 # Thanks to Mark Cressey (onewireweewx) and Howard Walter (TAI code).
@@ -169,7 +169,7 @@ import weewx
 from weewx.drivers import AbstractDevice
 from weewx.engine import StdService
 
-VERSION = "0.11"
+VERSION = "0.13"
 
 def logmsg(level, msg):
     syslog.syslog(level, 'owfs: %s' % msg)
@@ -231,7 +231,7 @@ def average(key, path, last_data, ts):
     return x
 
 def rainwise_bucket(key, path, last_data, ts):
-    cnt = delta(key, "%s%s" % (path, "/counters.B"), last_data, ts)
+    cnt = counter(key, "%s%s" % (path, "/counters.B"), last_data, ts)
     if cnt is not None:
         cnt *= 0.0254 # rainwise bucket is 0.01 inches per tip, convert to cm
     return cnt
@@ -404,8 +404,6 @@ class OWFSDriver(weewx.drivers.AbstractDevice):
         self.sensor_type = stn_dict.get('sensor_type', {})
         self.interface = stn_dict.get('interface', 'u')
         self.polling_interval = int(stn_dict.get('polling_interval', 10))
-        self.max_tries = int(stn_dict.get('max_tries', 3))
-        self.retry_wait = int(stn_dict.get('retry_wait', 5))
         self.unit_system = stn_dict.get('unit_system', 'METRIC').lower()
         self.last_data = {}
         self.units = weewx.US if self.unit_system == 'us' else weewx.METRIC
@@ -427,37 +425,28 @@ class OWFSDriver(weewx.drivers.AbstractDevice):
         return 'OWFS'
 
     def genLoopPackets(self):
-        ntries = 0
-        while ntries < self.max_tries:
-            ntries += 1
-            try:
-                last_data = dict(self.last_data)
-                p = {'usUnits': self.units,
-                     'dateTime': int(time.time() + 0.5)}
-                for s in self.sensor_map:
-                    st = 'gauge'
-                    if s in self.sensor_type:
-                        st = self.sensor_type[s]
-                    if st in SENSOR_TYPES:
+        while True:
+            last_data = dict(self.last_data)
+            p = {'usUnits': self.units,
+                 'dateTime': int(time.time() + 0.5)}
+            for s in self.sensor_map:
+                p[s] = None
+                st = 'gauge'
+                if s in self.sensor_type:
+                    st = self.sensor_type[s]
+                if st in SENSOR_TYPES:
+                    try:
                         func = SENSOR_TYPES[st]
                         p[s] = func(s, self.sensor_map[s],
                                     last_data, p['dateTime'])
-                    else:
-                        logerr("unknown sensor type '%s' for %s" % (st, s))
-                ntries = 0
-                self.last_data.update(last_data)
-                self.calculate_derived(p)
-                yield p
-                time.sleep(self.polling_interval)
-            except ow.exError, e:
-                logerr("Failed attempt %d of %d to get sensor data: %s" %
-                       (ntries, self.max_tries, e))
-                logdbg("Waiting %d seconds before retry" % self.retry_wait)
-                time.sleep(self.retry_wait)
-        else:
-            msg = "Max retries (%d) exceeded for sensor data" % self.max_tries
-            logerr(msg)
-            raise weewx.RetriesExceeded(msg)
+                    except ow.exError, e:
+                        logerr("Failed to get sensor data: %s" % e)
+                else:
+                    logerr("unknown sensor type '%s' for %s" % (st, s))
+            self.last_data.update(last_data)
+            self.calculate_derived(p)
+            yield p
+            time.sleep(self.polling_interval)
 
     def calculate_derived(self, data):
         if 'windSpeed' in data:
@@ -485,8 +474,6 @@ class OWFSService(weewx.engine.StdService):
         self.sensor_map = d['sensor_map']
         self.sensor_type = d.get('sensor_type', {})
         self.interface = d.get('interface', 'u')
-        self.max_tries = int(d.get('max_tries', 3))
-        self.retry_wait = int(d.get('retry_wait', 5))
         self.unit_system = d.get('unit_system', 'METRIC').lower()
         self.binding = d.get('binding', 'archive')
         self.last_data = {}
@@ -521,36 +508,29 @@ class OWFSService(weewx.engine.StdService):
     # if the packets to which we append are something other than metric, then
     # we do a conversion after we have all the data.
     def getData(self, packet):
-        ntries = 0
-        while ntries < self.max_tries:
-            ntries += 1
-            try:
-                last_data = dict(self.last_data)
-                p = {'usUnits': self.units}
-                for s in self.sensor_map:
-                    st = 'gauge'
-                    if s in self.sensor_type:
-                        st = self.sensor_type[s]
-                    if st in SENSOR_TYPES:
-                        func = SENSOR_TYPES[st]
-                        p[s] = func(s, self.sensor_map[s],
-                                    last_data, packet['dateTime'])
-                    else:
-                        logerr("unknown sensor type '%s' for %s" % (st, s))
-                self.last_data.update(last_data)
-                break
-            except ow.exError, e:
-                logerr("Failed attempt %d of %d to get onewire data: %s" %
-                       (ntries, self.max_tries, e))
-                logdbg("Waiting %d seconds before retry" % self.retry_wait)
-                time.sleep(self.retry_wait)
-        else:
-            msg = "Max retries (%d) exceeded for onewire data" % self.max_tries
-            logerr(msg)
+        last_data = dict(self.last_data)
+        p = {'usUnits': self.units}
+        for s in self.sensor_map:
+            p[s] = None
+            st = 'gauge'
+            if s in self.sensor_type:
+                st = self.sensor_type[s]
+            if st in SENSOR_TYPES:
+                func = SENSOR_TYPES[st]
+                try:
+                    p[s] = func(s, self.sensor_map[s],
+                                last_data, packet['dateTime'])
+                except ow.exError, e:
+                    logerr("Failed to get onewire data: %s" % e)
+            else:
+                logerr("unknown sensor type '%s' for %s" % (st, s))
+        self.last_data.update(last_data)
 
         if packet['usUnits'] != self.units:
+            p['usUnits'] = self.units
             converter = weewx.units.StdUnitConverters[packet['usUnits']]
             p = converter.convertDict(p)
+            del p['usUnits']
         return p
 
 # define a main entry point for basic testing without weewx engine and service
